@@ -5,7 +5,7 @@
 #include <string.h>
 
 #include "../../configure.h" //e.g. DATA_DIR
-#include "../jammo-track-view.h"
+#include "../jammo-editing-track-view.h"
 #include "../jammo-cursor.h"
 #include "../jammo-mentor.h"
 #include "../jammo.h"
@@ -85,7 +85,7 @@ static gboolean save_image_pressed(TangleButton *tanglebutton, gpointer data){
 	gchar* additional_metadata = g_strdup_printf("\"icon\" : \"%s\",\n\"theme\" : \"%s\",\n\"variation\" : %d,\n",name_of_icon,theme->name,theme->variation);
 
 	//save composition will return filename, but we are not interested in
-	g_free(save_composition(filename_for_saving, jammo_get_actor_by_id("composition_game_container_for_tracks"),additional_metadata));
+	g_free(save_composition(filename_for_saving, clutter_actor_get_parent(CLUTTER_ACTOR(theme->bottom_track_view)) ,additional_metadata));
 
 	g_free(filename_for_saving);
 	g_free(additional_metadata);
@@ -106,15 +106,9 @@ return sin (phasing(clutter_timeline_get_progress (clutter_alpha_get_timeline (a
 static int tempo_table[] = {0,140,110,90}; //variation1 is 140bpm, variation2 is 110bpm, variation3 is 90pbm
 
 //On advanced game, variation is not used, they are all using same set of sample_buttons
-ClutterActor* theme_give_sample_button_for_this_theme_and_variation_for_this_id(gchar* themename, guint variation, guint id){
-	gchar *name;
-	if (chum_is_easy_game())
-		name = g_strdup_printf("composition_game_theme_%s_%d_id%d", themename,tempo_table[variation],id);
-	else
-		name = g_strdup_printf("composition_game_theme_%s_advanced_id%d", themename,id);
+ClutterActor* theme_give_sample_button_for_this_theme_and_variation_for_this_id(jammo_theme* theme, gchar* themename, guint variation, guint id){
 
-	JammoSampleButton* sb = JAMMO_SAMPLE_BUTTON(jammo_get_actor_by_id(name)); //clone this!
-	g_free(name);
+	JammoSampleButton* sb = JAMMO_SAMPLE_BUTTON(g_ptr_array_index(theme->sample_button_array, id)); //clone this!
 	//It is unique, we can't return it.  We make clone of it.
 
 	ClutterActor* sample_button;
@@ -147,6 +141,7 @@ static void unpause_actors_animation(ClutterActor *actor, gpointer user_data) {
 	}
 }
 
+static int static_counter_for_id = 0;
 /*
 This function creates new jammo_sample_button from given parameters and put it to given parent ClutterActor.
 */
@@ -161,14 +156,14 @@ static void create_samplebutton(gchar* themename, gchar* variation, gchar* image
 	*animated
 	   sample_buttons
 	just make textures*/
-
+/*
 	if (theme->only_playing_mode) {
 		ClutterActor* icon = clutter_texture_new_from_file(full_image, NULL);
 		clutter_actor_set_position(icon, x, y);
 		tangle_widget_add(parent, icon, NULL);
 		return;
 		}
-
+*/
 
 	//This is good place to do menu for selecting icon for saved composition
 	if (x_place_for_icon<500) { //if 500px is used do not add anymore icons
@@ -192,6 +187,11 @@ static void create_samplebutton(gchar* themename, gchar* variation, gchar* image
 	jammo_sample_button_set_image_filename(JAMMO_SAMPLE_BUTTON(sample_button),full_image);
 	jammo_sample_button_set_sample_filename(JAMMO_SAMPLE_BUTTON(sample_button),full_sound);
 
+	jammo_sample_button_set_loop_id(JAMMO_SAMPLE_BUTTON(sample_button), theme->sample_button_array->len);
+	g_ptr_array_add(theme->sample_button_array, sample_button);
+	static_counter_for_id++;
+
+
 	//Each animation has own phase
 	int phase = (rand () % 100) + 1;
 	//printf("phase %d\n",phase);
@@ -254,7 +254,11 @@ static ClutterActor* create_soundfamily_button(const gchar* theme_name, const gc
 
 	//For pausing and unpausing hidden animations
 	g_signal_connect(widget, "hide", G_CALLBACK(pause_actors_animation), NULL);
-	g_signal_connect(widget, "show", G_CALLBACK(unpause_actors_animation), NULL);
+
+	//Do not ever start animations on pair-game:
+	if (!chum_get_pair_composition()) {
+		g_signal_connect(widget, "show", G_CALLBACK(unpause_actors_animation), NULL);
+	}
 
 	gchar* filename = g_strdup_printf("%s/%s/advanced/%s", THEMES_DIR, theme_name,button_name);
 	ClutterActor *menu_button =  tangle_button_new_with_background_actor(clutter_texture_new_from_file(filename, NULL));
@@ -368,9 +372,9 @@ static void on_sequencer_stopped(JammoSequencer* sequencer, gpointer data) {
 	else //easy-game
 		theme_play_all_icon_animations(theme);
 
-	jammo_track_view_set_editing_enabled(theme->bottom_track_view, TRUE);
+	jammo_editing_track_view_set_editing_enabled(theme->bottom_track_view, TRUE);
 	if (theme->upper_track_view && !(chum_get_pair_composition())) {
-		jammo_track_view_set_editing_enabled(theme->upper_track_view, TRUE);
+		jammo_editing_track_view_set_editing_enabled(theme->upper_track_view, TRUE);
 	}
 
 
@@ -409,10 +413,10 @@ static void remove_all_icon_animations(jammo_theme* theme) {
 
 jammo_theme* theme_create(const gchar* name,int variation, gboolean only_listening, ClutterActor* play_button) {
 	x_place_for_icon = 0; //static (used only when initializing new theme)
-
 	jammo_theme* theme;
 	theme = g_new( jammo_theme, 1 );
 
+	theme->sample_button_array = g_ptr_array_new();
 	theme->only_playing_mode=only_listening;
 	theme->animation_timelines=NULL;
 	theme->play_button = play_button;
@@ -774,27 +778,27 @@ if (use_two_tracks) y_offset=80;
 	//Bottom track. Below of this there will be place for scrollbar.
 	JammoEditingTrack* editing_track_theme = jammo_editing_track_new_fixed_duration(number_of_slots*slot_duration);
 	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(editing_track_theme));
-	ClutterActor*	track_view = jammo_track_view_new(editing_track_theme, number_of_slots,slot_duration, WIDTH_OF_SLOT, 80.0);
+	ClutterActor*	track_view = jammo_editing_track_view_new(editing_track_theme, number_of_slots,slot_duration, WIDTH_OF_SLOT, 80.0);
 	g_object_set(track_view, "disabled-slots-begin", disabled_slots_for_begin, "disabled-slots-end", disabled_slots_for_end,NULL);
 	clutter_actor_set_reactive(track_view, TRUE);
 	g_object_set(track_view, "line-every-nth-slot", 2, NULL);
 	clutter_actor_set_position(track_view, 0.0, 2.0+y_offset);
 	tangle_widget_add(TANGLE_WIDGET(container_for_tracks), track_view, NULL);
 
-	theme->bottom_track_view = JAMMO_TRACK_VIEW(track_view); //This is needed when loading/saving
+	theme->bottom_track_view = JAMMO_EDITING_TRACK_VIEW(track_view); //This is needed when loading/saving
 	theme->upper_track_view = NULL; //This will be NULL, if use_two_tracks is not TRUE.
 
 	if (use_two_tracks){
 	//Upper track.
 	JammoEditingTrack* editing_track_theme2 = jammo_editing_track_new_fixed_duration(number_of_slots*slot_duration);
 	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(editing_track_theme2));
-	ClutterActor* track_view2 = jammo_track_view_new(editing_track_theme2, number_of_slots,slot_duration, WIDTH_OF_SLOT, 80.0);
+	ClutterActor* track_view2 = jammo_editing_track_view_new(editing_track_theme2, number_of_slots,slot_duration, WIDTH_OF_SLOT, 80.0);
 
 
 	//pair-game:
 	if (chum_get_pair_composition()) {
 		printf("pairgame\n");
-		jammo_track_view_set_editing_enabled(JAMMO_TRACK_VIEW(track_view2),FALSE);
+		jammo_editing_track_view_set_editing_enabled(JAMMO_EDITING_TRACK_VIEW(track_view2),FALSE);
 		g_object_set(chum_get_pair_composition(),"peer-track-view", track_view2,NULL); //this will handle all other things
 	}
 	else {
@@ -807,7 +811,7 @@ if (use_two_tracks) y_offset=80;
 	clutter_actor_set_position(track_view2, 0.0, 2.0);
 	tangle_widget_add(TANGLE_WIDGET(container_for_tracks), track_view2, NULL);
 
-	theme->upper_track_view = JAMMO_TRACK_VIEW(track_view2); //This is needed when loading/saving
+	theme->upper_track_view = JAMMO_EDITING_TRACK_VIEW(track_view2); //This is needed when loading/saving
 	}
 
 	//Scrolling area for track (or tracks)
@@ -850,6 +854,8 @@ void delete_theme(jammo_theme* theme){
 		g_list_free(theme->animation_timelines);
 	}
 
+	g_ptr_array_free(theme->sample_button_array,TRUE);
+
 	//TODO, free everything.
 	if (theme->save_menu_container != NULL){
 	clutter_actor_destroy(theme->save_menu_container);
