@@ -24,7 +24,7 @@ View contains three part:
 
 #include "../jammo.h"
 #include "../jammo-mentor.h"
-#include "../jammo-track-view.h"
+#include "../jammo-editing-track-view.h"
 #include "../jammo-miditrack-view.h"
 #include "../../cem/cem.h"
 
@@ -85,10 +85,6 @@ g_assert (object != NULL);
 	gint tempo = 110; //'normal' tempo
 	gchar* pitch ="D";  //'normal' pitch
 
-
-	//gint slot;    //TODO: not used
-	//gint loop_id; //TODO: function missing
-
 	//META data: Load these only once
 if (load_only_backingtrack){
 	//int
@@ -280,7 +276,7 @@ if (load_only_backingtrack){
 							if (sample_button==NULL)
 								printf("Loading loop-id '%d' from file: sample_button==NULL, can't add to track.\n",loop_id);
 							else
-								jammo_track_view_add_jammo_sample_button(JAMMO_TRACK_VIEW(track_view),JAMMO_SAMPLE_BUTTON(sample_button),slot);
+								jammo_editing_track_view_add_jammo_sample_button(JAMMO_EDITING_TRACK_VIEW(track_view),JAMMO_SAMPLE_BUTTON(sample_button),slot);
 
 						} //This sample-object is ready
 
@@ -342,7 +338,7 @@ if (load_only_backingtrack){
 			//Tune volume, mute, etc.
 			//In case of slider and backing_track, we already have 'track'
 			if (!track) {
-				if (track_view && (JAMMO_IS_TRACK_VIEW(track_view) || JAMMO_IS_MIDITRACK_VIEW(track_view)))
+				if (track_view && (JAMMO_IS_EDITING_TRACK_VIEW(track_view) || JAMMO_IS_MIDITRACK_VIEW(track_view)))
 					g_object_get(track_view,"track",&track,NULL);
 			}
 
