@@ -391,7 +391,7 @@ static void on_sample_stopped(JammoSample* sample, gpointer user_data) {
 	g_object_unref(mentor->priv->active_sample);
 	mentor->priv->active_sample = NULL;
 
-	if (next_speech) {
+	if (next_speech && !mentor->priv->interrupted) {
 		real_speak(mentor, next_speech, callback, speech, data);
 	} else {
 
