@@ -43,14 +43,14 @@ verify_path (ClutterRectangle *rect, ClutterEvent *event, ClutterActor *containe
 	 if (check==1)
 	 {
 	 	 g_print("\nWelcome :)\n");
-	 	 clutter_actor_show(avatar);
 	 	 clutter_actor_hide(container);
 	 	 create_ink_tale();
 	 	 clutter_actor_show(jammo_get_actor_by_id("main-menu-view"));
 	 	 clutter_actor_hide(jammo_get_actor_by_id("pen-gesture-view"));
 	 }else{
  		 g_print("Wrong pass\n");
- 		 clutter_actor_hide(avatar);
+ 		 clutter_actor_show(avatar);
+ 		 clutter_actor_hide(container);
      }
 
 	check=0;
@@ -151,16 +151,13 @@ show_points_container(ClutterActor *box,
 {
 
 	clutter_actor_show(container);
+	clutter_actor_hide(avatar);
     return FALSE;
 }
 
-
-
-
 void login_screen()
 {
-  //ClutterColor stage_color = { 0x00, 0x00, 0x00, 0xff };
-  //ClutterColor actor_cp_color = { 0x00, 0x00, 0x00, 0xff };
+  //ClutterColor pg_black_color = { 0x00, 0x00, 0x00, 0xff };
 
   //Initialize buffer for storing activated knots
   initialize_knots_buffer();
@@ -212,12 +209,12 @@ void login_screen()
   */
   //Create Buttons
   button_exit_set(stage);
-  button_action_set(stage);
+  //button_action_set(stage);
   //button_new_gesture_set(stage);
-  button_ok_set(stage);
+  //button_ok_set(stage);
   //button_next_set(stage);
   //button_back_set(stage);
-  button_cancel_set(stage);
+  //button_cancel_set(stage);
   //ClutterActor *avatar;
   avatar=button_avatar_set(stage);
   clutter_actor_hide(avatar);
@@ -277,6 +274,8 @@ void login_screen()
   g_signal_connect(stage,"button-press-event", G_CALLBACK(show_points_container),point_container);
    /* Show the stage: */
   clutter_actor_hide(point_container);
+  clutter_actor_set_reactive(point_container, FALSE);
+
 
   clutter_actor_show(stage);
 
